//******************************************************************************************************************
// dtmf_relay.ino
// Read DTMF codes from MT8870 module and activate a relay + send tone confirmation.  George Thomas, W5JDX 11/11/2018
//******************************************************************************************************************

//establish pin uses
int STQ = 8;                    // DTMF Module STQ Pin connects to Arduino Digital Pin 8
int Q4 = 12;                    // DTMF Module Q4  Pin connects to Arduino Digital Pin 12
int Q3 = 11;                    // DTMF Module Q3  Pin connects to Arduino Digital Pin 11
int Q2 = 10;                    // DTMF Module Q2  Pin connects to Arduino Digital Pin 10
int Q1 = 9;                     // DTMF Module Q1  Pin connects to Arduino Digital Pin 9

int controlledRelayPin = 6;     // Controlled relay driver connects to Arduino Digital Pin 6
int pttRelayPin = 7;            // PTT relay driver connects to Arduino Digital Pin 7

int tonePin = 13;               // Specify pin used for tone function

void setup()        // ---------- initialize the Arduino ----------
{
  pinMode(STQ, INPUT);          //set Digital I/O pin functions
  pinMode(Q4, INPUT);
  pinMode(Q3, INPUT);
  pinMode(Q2, INPUT);
  pinMode(Q1, INPUT);
  pinMode(controlledRelayPin, OUTPUT);
  pinMode(pttRelayPin, OUTPUT);
  pinMode(tonePin, OUTPUT);
  
  Serial.begin(9600);           //open port to write val to serial port for debugging
  Serial.println("Begin dtmf_relay Program");
}

void loop()         // ---------- main loop of program ---------- 
{  
  if (digitalRead(STQ) == HIGH) // IF STQ is High a DTMF tone is present. Check 4-bit code.
  {
    getData();                  //call function to get the key pressed
  }
  delay(20);                    //delay 20 ms before repeating
}

void getData()      // ---------- read data from DTMF Decoder  ---------- 
{
  byte DTMFdata = 0;            // Initialize variables
  int i = 0;
                                //combine the incomming data from the 4 pins into a single byte
  if (digitalRead(Q1) == HIGH)  // If Q1 High add 1 to DTMFdata
  {
    DTMFdata = DTMFdata + 1;
  }
  if (digitalRead(Q2) == HIGH)  // If Q2 High add 2 to DTMFdata
  {
    DTMFdata = DTMFdata + 2;
  }
  if (digitalRead(Q3) == HIGH)  // If Q3 High add 4 to DTMFdata
  {
    DTMFdata = DTMFdata + 4;
  }
  if (digitalRead(Q4) == HIGH)  // If Q4 High add 8 to DTMFdata
  {
    DTMFdata = DTMFdata + 8;
  }

  Serial.print("DTMF Code = "); //print the code to the screen for debugging
  Serial.println(DTMFdata);
  
  switch (DTMFdata)             // execute command for code received
  {
    case 0:  //D
      break;
    case 1:  //1
      break;
    case 2:  //2
      break;
    case 3:  //3
      break;
    case 4:  //4
      break;
    case 5:  //5
      break;
    case 6:  //6
      break;
    case 7:  //7
      break;
    case 8:  //8
      break;
    case 9:  //9
     break;
    case 10:  //0
      break;
    case 11:  //* .......................... Turn OFF Relay
      digitalWrite(controlledRelayPin, LOW);        //turn the controlled relay off
      delay(1500);                                  //wait 1.5 seconds for user to unkey radio
      digitalWrite(pttRelayPin, HIGH);              //key the radio PTT
      delay(500);                                   //wait 1/2 second for radio to key
      sendId(tonePin);                              //id the radio first
      delay(250);                                   //wait 1/4 second
      tone(tonePin, 650, 150);                      //play a 650 hz tone ' tone(pin number, frequency in Hz, length in ms) '
      delay(150);                                   //wait 300 ms for 1st tone to play
      tone(tonePin, 500, 150);                      //play a 500 hz tone ' tone(pin number, frequency in Hz, length in ms) '
      delay(300);                                   //wait 300 ms for 2nd tone to play + 300 ms more
      digitalWrite(pttRelayPin, LOW);               //release the radio PTT
      Serial.println("Relay Turned OFF");           //print the action to the screen for debugging
      break;
    case 12:  //# .......................... Turn ON Relay
      digitalWrite(controlledRelayPin, HIGH);       //turn the controlled relay on
      delay(1500);                                  //wait 1.5 seconds for user to unkey radio
      digitalWrite(pttRelayPin, HIGH);              //key the radio PTT
      delay(500);                                   //wait 1/2 second for radio to key
      sendId(tonePin);                              //id the radio first
      delay(250);                                   //wait 1/4 second
      tone(tonePin, 500, 150);                      //play a 500 hz tone ' tone(pin number, frequency in Hz, length in ms) '
      delay(150);                                   //wait 300 ms for 1st tone to play
      tone(tonePin, 650, 150);                      //play a 650 hz tone ' tone(pin number, frequency in Hz, length in ms) '
      delay(300);                                   //wait 300 ms for 2nd tone to play + 300 ms more
      digitalWrite(pttRelayPin, LOW);               //release the radio PTT
      Serial.println("Relay Turned ON");            //print the action to the screen for debugging
      break;
    case 13:  //A
      break;
    case 14:  //B
      break;
    case 15:  //C
      break;
  }
}

